@@ -85,18 +85,36 @@ class RecordQualityResults(QualityHandler):
 
 
 class RemoveFailedValues(QualityHandler):
-    """Replace all the failed values with _FillValue
+    """Replace all the failed values with _FillValue.
+
+    Takes an optional `additional_variables` parameter, which, if provided, must
+    be a list of variable names that should also be set to _FillValue at the 
+    failed indices returned by the `QualityChecker`. For example:
+
+    .. code-block:: yaml
+
+        ...
+        classname: tsdat.qc.handlers.RemoveFailedValues
+        parameters:
+          # Additional variables to add (optional)
+          additional_variables: ["current_direction", "current_speed"]
+
     """
     def run(self, variable_name: str, results_array: np.ndarray):
         if results_array.any():
-            fill_value = DSUtil.get_fill_value(self.ds, variable_name)
-            keep_array = np.logical_not(results_array)
 
-            var_values = self.ds[variable_name].data
-            replaced_values = np.where(keep_array, var_values, fill_value)
-            self.ds[variable_name].data = replaced_values
+            variable_names = [variable_name]
+            variable_names.extend(self.params.get("additional_variables", []))
 
-            self.record_correction(variable_name)
+            for i, var_name in enumerate(variable_names):
+                fill_value = DSUtil.get_fill_value(self.ds, var_name)
+                keep_array = np.logical_not(results_array)
+
+                var_values = self.ds[var_name].data
+                replaced_values = np.where(keep_array, var_values, fill_value)
+                self.ds[var_name].data = replaced_values
+
+                self.record_correction(var_name)
 
 
 class SortDatasetByCoordinate(QualityHandler):
